@@ -1,5 +1,5 @@
 use std::{
-    collections::HashMap,
+    collections::BTreeMap,
     ffi::OsString,
     fs,
     fs::File,
@@ -8,7 +8,7 @@ use std::{
 };
 
 use clap::{App, Arg};
-use pyxis_parcel::{FileAdd, InodeAttr, Parcel};
+use pyxis_parcel::{FileAdd, InodeAttr, ParcelHandle, ReaderWriter};
 use walkdir::WalkDir;
 
 fn main() {
@@ -17,23 +17,25 @@ fn main() {
         .author("chordtoll <git@chordtoll.com>")
         .about("Creates parcel archive files for the pyxis package manager")
         .arg(
-            Arg::with_name("output")
+            Arg::new("output")
                 .value_name("OUTPUT")
                 .help("The output parcel to generate")
-                .takes_value(true),
+                .takes_value(true)
+                .required(true),
         )
         .arg(
-            Arg::with_name("input")
+            Arg::new("input")
                 .value_name("INPUT")
                 .help("The input directory to scan")
-                .multiple(true)
-                .takes_value(true),
+                .multiple_occurrences(true)
+                .takes_value(true)
+                .required(true),
         )
         .get_matches();
 
-    let mut parcel: Parcel = Parcel::new();
+    let mut parcel: ParcelHandle = ParcelHandle::new();
 
-    let mut dir_map: HashMap<PathBuf, u64> = HashMap::new();
+    let mut dir_map: BTreeMap<PathBuf, u64> = BTreeMap::new();
     dir_map.insert(PathBuf::from("/"), 1);
 
     for input in matches.values_of("input").unwrap() {
@@ -48,7 +50,7 @@ fn main() {
 
             if file_type.is_file() {
                 let attrs = InodeAttr::from_meta(&meta);
-                let mut xattrs: HashMap<OsString, Vec<u8>> = HashMap::new();
+                let mut xattrs: BTreeMap<OsString, Vec<u8>> = BTreeMap::new();
                 for attr in xattr::list(entry.path()).unwrap() {
                     xattrs.insert(
                         attr.clone(),
@@ -68,7 +70,7 @@ fn main() {
                     .unwrap();
             } else if file_type.is_dir() {
                 let attrs = InodeAttr::from_meta(&meta);
-                let mut xattrs: HashMap<OsString, Vec<u8>> = HashMap::new();
+                let mut xattrs: BTreeMap<OsString, Vec<u8>> = BTreeMap::new();
                 for attr in xattr::list(entry.path()).unwrap() {
                     xattrs.insert(
                         attr.clone(),
@@ -82,7 +84,7 @@ fn main() {
                     .unwrap();
             } else if file_type.is_symlink() {
                 let attrs = InodeAttr::from_meta(&meta);
-                let mut xattrs: HashMap<OsString, Vec<u8>> = HashMap::new();
+                let mut xattrs: BTreeMap<OsString, Vec<u8>> = BTreeMap::new();
                 for attr in xattr::list(entry.path()).unwrap() {
                     xattrs.insert(
                         attr.clone(),
@@ -105,7 +107,7 @@ fn main() {
                     .unwrap();
             } else if file_type.is_char_device() {
                 let attrs = InodeAttr::from_meta(&meta);
-                let mut xattrs: HashMap<OsString, Vec<u8>> = HashMap::new();
+                let mut xattrs: BTreeMap<OsString, Vec<u8>> = BTreeMap::new();
                 for attr in xattr::list(entry.path()).unwrap() {
                     xattrs.insert(
                         attr.clone(),
@@ -130,5 +132,6 @@ fn main() {
     }
 
     let outfile = File::create(matches.value_of("output").unwrap()).unwrap();
-    parcel.store(outfile).unwrap();
+    parcel.set_file(Box::new(ReaderWriter::new(outfile)));
+    parcel.store().unwrap();
 }
